@@ -571,12 +571,12 @@ class Curve:
         #    self.__qlcalendar = ql.NullCalendar()  
 
     @property
-    def deposit(self):
-        return self.__deposit
+    def deposits(self):
+        return self.__deposits
 
-    @deposit.setter
-    def deposit(self, deposit):
-        self.__deposit = deposit  
+    @deposits.setter
+    def deposits(self, deposits):
+        self.__deposits = deposits 
 
     @property
     def parbond(self):
@@ -617,9 +617,12 @@ class Curve:
         else:
             vdate = ql.Settings.instance().evaluationDate
         
-        helpers = self.__deposits.helpers()
-        helpers += self.__parbond.helpers()
-        
+
+        helpers = []
+        if self.__deposits:
+            helpers += self.__deposits.helpers()
+        if self.__parbond:
+            helpers += self.__parbond.helpers()
         if self.__fra:
             helpers += self.__fra.helpers()
         if self.__ois:
